describe_models

site.SiteProblem.describe_models(available_only=True)

Prints a menu of available optimization strategies for healthcare.

Parameters

Name Type Description Default
available_only bool Whether to limit the printout to only the models that are currently supported by the library rather than all methods True
Back to top