get_metric_summary
site_solutions.SolutionComparator.get_metric_summary(
objective='weighted_average',
)Returns a comparison of descriptive statistics for a specific objective.
Returns a comparison of descriptive statistics for a specific objective.