return_best_combination_details

site.SiteSolutionSet.return_best_combination_details(rank_on=None, top_n=1)

Return details of the top-ranked solution(s).

Parameters

Name Type Description Default
rank_on str Column name to sort the solutions by. If provided, solutions are sorted in ascending order before selecting the top entries. If None, the existing order of solution_df, which is based on the objective selected, is used. None
top_n int Number of top solutions to return. 1

Returns

Name Type Description
pandas.DataFrame DataFrame containing the top top_n solutions, including all available columns. The index is reset in the returned DataFrame.

Notes

Sorting is performed in ascending order, so lower values are assumed to represent better solutions for the specified ranking metric.

Back to top