Return the site names for the best-performing solution.
Parameters
Name
Type
Description
Default
sort_by
str
Column name to rank the solutions by. If provided, the solution with the BEST value in this column is selected – the highest for coverage proportions, the lowest for travel-cost metrics. If None, the existing order of solution_df, which is based on the objective selected, is used.
None
Returns
Name
Type
Description
object
The value of the “site_names” column for the best solution. Typically a list or array of site names.