Return the site names for the best-performing solution.
Parameters
Name
Type
Description
Default
rank_on
str
Column name to sort the solutions by. If provided, the solution with the lowest value in this column is selected. If None, the existing order of solution_df, which is based on the objective selected, is used.
None
Returns
Name
Type
Description
object
The value of the “site_indices” column for the best solution. Typically a list or array of site indices.