site_solutions.SolutionComparator
site_solutions.SolutionComparator(
solution_set_a,
solution_set_b,
labels=('Set A', 'Set B'),
)Tools to compare two SiteSolutionSet objects.
Methods
| Name | Description |
|---|---|
| compare_top_results | Compares the top N solutions from both sets. |
| get_metric_summary | Returns a comparison of descriptive statistics for a specific objective. |
| compare_site_allocation | Compare site_allocation_summary() between set_a and set_b, |
| population_impact_summary | How many people’s journey actually changed between set_a and |
| population_impact_phrase | Stakeholder-facing sentence summarising population_impact_summary(), |
| site_overlap | Analyzes how many sites are common between the top N solutions |
| plot_comparison | Plot solutions from both solution sets side-by-side. |
| plot_population_impact_summary | Two-panel bar chart pairing population_impact_summary()’s |
| plot_population_impact_histogram | Overlaid before/after distribution of per-region travel cost – |